@@ -1,7 +1,7 @@
 package Twitter::API;
 # ABSTRACT: A Twitter REST API library for Perl
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 use 5.14.1;
 use Moo;
 use Carp;
@@ -18,7 +18,7 @@ use URL::Encode ();
 use WWW::OAuth;
 use namespace::clean;
 
-with qw/MooX::Traits Twitter::API::Transition/;
+with qw/MooX::Traits Twitter::API::Migration/;
 sub _trait_namespace { 'Twitter::API::Trait' }
 
 has [ qw/consumer_key consumer_secret/ ] => (
@@ -230,23 +230,29 @@ sub add_authorization {
 
     my $req = $c->http_request;
 
-    my %oauth_args = (
+    my %cred = (
         client_id     => $self->consumer_key,
         client_secret => $self->consumer_secret,
     );
 
-    my $extra_args = $c->get_option('oauth_args');
-    unless ( $extra_args ) {
-        $oauth_args{token} = $c->get_option('token')
+    my %oauth;
+    # only the token management methods set 'oauth_args'
+    if ( my $opt = $c->get_option('oauth_args') ) {
+        %oauth = %$opt;
+        $cred{token}        = delete $oauth{oauth_token};
+        $cred{token_secret} = delete $oauth{oauth_token_secret};
+    }
+    else {
+        # protected request; requires tokens
+        $cred{token} = $c->get_option('token')
             // $self->access_token
             // croak 'requires an oauth token';
-        $oauth_args{token_secret} = $c->get_option('token_secret')
+        $cred{token_secret} = $c->get_option('token_secret')
             // $self->access_token_secret
             // croak 'requires an oauth token secret';
     }
 
-    my $oauth = WWW::OAuth->new(%oauth_args);
-    $oauth->authenticate($req, $extra_args || {});
+    WWW::OAuth->new(%cred)->authenticate($req, \%oauth);
 }
 
 around send_request => sub {
@@ -355,10 +361,12 @@ sub oauth_request_token {
     my $self = shift;
     my %args = @_ == 1 && ref $_[0] ? %{ $_[0] } : @_;
 
-    $args{oauth_callback} = delete $args{callback} // 'oob';
+    my %oauth_args;
+    $oauth_args{oauth_callback} = delete $args{callback} // 'oob';
     return $self->request(post => $self->oauth_url_for('request_token'), {
         -accept     => 'application/x-www-form-urlencoded',
-        -oauth_args => \%args,
+        -oauth_args => \%oauth_args,
+        %args, # i.e. ( x_auth_access_type => 'read' )
     });
 }
 
@@ -416,7 +424,7 @@ Twitter::API - A Twitter REST API library for Perl
 
 =head1 VERSION
 
-version 0.0105
+version 0.0106
 
 =head1 SYNOPSIS
 
@@ -557,9 +565,9 @@ inflate API call results to objects via L<Twitter::API::Trait::InflateObjects>
 
 =head2 Migration from Net::Twitter and Net::Twitter::Lite
 
-Transitional support is included to assist users migrating from L<Net::Twitter>
+Migration support is included to assist users migrating from L<Net::Twitter>
 and L<Net::Twitter::Lite>. It will be removed from a future release (or at
-least not included by default). See L<Twitter::API::Transition> for details
+least not included by default). See L<Twitter::API::Migration> for details
 about migrating your existing Net::Twitter/::Lite applications.
 
 =head2 Normal usage
@@ -575,9 +583,9 @@ for each.
 =head2 Minimalist usage
 
 Without any traits, Twitter::API provides access to API endpoints with the
-L<get> and L<post> methods described below, as well as methods for managing
-OAuth authentication. API results are simply perl data structures decoded from
-the JSON responses. Refer to the L<Twitter API
+L<get|get-url-args> and L<post|post-url-args> methods described below, as well
+as methods for managing OAuth authentication. API results are simply perl data
+structures decoded from the JSON responses. Refer to the L<Twitter API
 Documentation|https://dev.twitter.com/rest/public> for available endpoints,
 parameters, and responses.
 
